==> haskell-summoner-2.0.1.1-652-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-5RzeiuGOcTELRWheu5sWI2
key:                  summoner-2.0.1.1-5RzeiuGOcTELRWheu5sWI2
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  11b4015d3e8cc8d474f27d9f0fe22507
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner
hs-libraries:         HSsummoner-2.0.1.1-5RzeiuGOcTELRWheu5sWI2
depends:
    base-4.17.2.1 relude-1.2.2.2-4QKJ12AjjadGiCoCuzizMH
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    colourista-0.1.0.2-H7RKz6j0wA4Iuics6WxGGM containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    generic-data-1.1.0.2-BDZVMn5UWzA52pwOmHLMNp
    gitrev-1.3.1-KhpMNofwsxABRoyEGWB0ci
    neat-interpolation-0.5.1.4-FtOUjEeg3uZKUKNQdqfNCl
    optparse-applicative-0.18.1.0-3qYZezrQAxc4lJKAil0WN1
    process-1.6.18.0 shellmet-0.0.5.0-8Yik2KTBj0R59WE9FnjtZa text-2.0.2
    time-1.12.2 tomland-1.3.3.3-JFgkYduYdstDoszIPoI5bL
    validation-selective-0.2.0.0-KNcNnqq7Psg3gF5VFYAuSu

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-2.0.1.1-675-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-D9H2GcKjLl1Ipab1HQWm3u
key:                  summoner-2.0.1.1-D9H2GcKjLl1Ipab1HQWm3u
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  4f348993d853399de9c7c141ad2c377b
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner
hs-libraries:         HSsummoner-2.0.1.1-D9H2GcKjLl1Ipab1HQWm3u
depends:
    base-4.17.2.1 relude-1.2.2.2-Bl8jl1Mjkjo7ysD7Vb9Fux
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    colourista-0.1.0.2-Lo9Z9wdKunE9ASTA6VvG91 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    generic-data-1.1.0.2-TgCVfjFyla9MwzqrF7tfU
    gitrev-1.3.1-EAQEu0I0MYZ3NOvBCjPIAO
    neat-interpolation-0.5.1.4-7XPSlxvtItq5pBrn3Wiexy
    optparse-applicative-0.18.1.0-t4C6chS8YH5x9x9VuRkT0
    process-1.6.18.0 shellmet-0.0.5.0-JJefjMwgpMb3tpXTZs84mz text-2.0.2
    time-1.12.2 tomland-1.3.3.3-Bb5cycrusRp4CwNRg5b7Rr
    validation-selective-0.2.0.0-CbJsyvwdVL05TZFQ8E5cjs

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
